powered by
Check WPX list for legitimate picks
legitWPX(twpx, quiet=TRUE)
integer: 0=not legitimate, 1=legitimate
pick information list (WPX)
logical, default=TRUE, FALSE generates an error message
Jonathan M. Lees<[email protected]>
Used internall to test if a WPX list has legitimate picks. Initially a list is generated with NA and 0 values in the place holders. If no legitimate picks are added, the list still exists, but the picks are bogus, so this routine will return 0.
PCsaveWPX
### test fails library(RSEIS) jk = RSEIS::cleanWPX() legitWPX(jk) #### test passes: data(GH, package='RSEIS') gwpx = RSEIS::uwpfile2ypx(GH$pickfile) legitWPX(gwpx)
Run the code above in your browser using DataLab